@@ -1,15 +1,16 @@
-from dataclasses import dataclass
-from typing import List
-from .interface import Interface
 import ipaddress
+from dataclasses import dataclass
+
+from .interface import Interface
+
 
 @dataclass
 class Network:
-    default_gateway: str
-    ips: List[str]
+    default_gateway: ipaddress.IPv4Address
+    ips: ipaddress.IPv4Network
 
     @classmethod
     def from_interface(cls, interface: Interface):
-        network =  ipaddress.IPv4Network(f'{interface.address}/{interface.prefix_length}', strict=False)
+        network = ipaddress.IPv4Network(f'{interface.address}/{interface.prefix_length}', strict=False)
         default_gateway = network[1]
-        return cls(default_gateway, network)
\ No newline at end of file
+        return cls(default_gateway, network)
